========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/sahara-extra.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

OpenStack Data Processing ("Sahara") extra repo
===============================================

Sahara-extra is place for Sahara components not included into the main `Sahara repository <https://github.com/openstack/sahara>`_

Here is the list of components:

* Sources for Swift filesystem implementation for Hadoop: http://git.openstack.org/cgit/openstack/sahara-extra/tree/hadoop-swiftfs/README.rst
* Sources for main function wrapper that adapt for oozie: http://git.openstack.org/cgit/openstack/sahara-extra/tree/edp-adapt-for-oozie/README.rst
* Sources for main function wrapper that adapt for spark: http://git.openstack.org/cgit/openstack/sahara-extra/tree/edp-adapt-for-spark/README.rst
* `Diskimage-builder <http://git.openstack.org/cgit/openstack/diskimage-builder>`_ elements moved to the new repo: http://git.openstack.org/cgit/openstack/sahara-image-elements
* Tools for building artifacts: http://git.openstack.org/cgit/openstack/sahara-extra/tree/tools
